%************************************************************************
%
% Mathlab simulation giving values of aplha2 for a range values of alpha1
%
% Where the cloud cover at each height is Beta(a,b) distributed
%
%************************************************************************
a=1;b=1;%Set values of a and b for Beta(a,b)
rho=1;% Set vertical correlation coefficient rho (c1a v c1b)
R=0;% Set horizontal correlation coeffcient R (c1a v c2a)
r2=rho*R;%Set diagonal correlation coefficient (c1a v c2b)
Rh = [1 R rho r2;R 1 r2 rho;rho r2 1 R;r2 rho R 1];% Create correlation matrix Rh
n = 2000;% Set number n of simulated values for c1a, c2a, c1b and c2b
k=6;a1=((1:k)-1)/(k-1);a2=a1*0;%Create arrays of length k for alpha1 & alpha2
for j=drange(1,k);% Loop through the k created values for aplha1
% Create arrays c1a c2a c1b c2b of correlated Beta(a,b)distributed cloud cover values 
U = betainv(normcdf(mvnrnd([0 0 0 0],Rh,n)),a,b);c1a=U(:,1);c2a=U(:,2);c1b=U(:,3);c2b=U(:,4);
% Generate overlap cm1, cm2, cr1 and cr2 using definitions for cmax and crandom
cm1=max(c1a,c1b);cr1=c1a+c1b-c1a.*c1b;cm2=max(c2a,c2b);cr2=c2a+c2b-c2a.*c2b;
% Generate means of ct1 and ct2 using the definition of Hogan & Illingworth (2000)
ct1bar=a1(j)*mean((cm1-cr1))+mean(cr1);ct2bar=a1(j)*mean(cm2-cr2)+mean(cr2);
% Detemine c1, c2, cmax, crandom and the mean of ct for a gridbox with twice size
c11=(c1a+c2a)/2.0;c22=(c1b+c2b)/2.0;ctbar=(ct1bar+ct2bar)/2.0;cmm=max(c11,c22);crr=c22+c11-c22.*c11;
a2(j)=(ctbar-mean(crr))/(mean(cmm)-mean(crr));% Determine alpha2
end;
scatter(a1,a2,'black');xlabel('\fontsize{16}\alpha_1');ylabel('\fontsize{16}\alpha_2');%Plot alpha1 v alpha2 & label plot
title(['\fontsize{16}\beta(',num2str(a),',',num2str(b),')    \rho = ',num2str(rho),'    \itR = ',num2str(R)]);%Title
ylim([0,1]);xlim([0,1]);hold on;plot([0 1],[0 1],'--black');%Plot line y=x
[p,s]=polyfit(a1,a2,1);plot(a1,polyval(p,a1),'black');%Plot best-fit straight line
text(.2,.05,['\fontsize{14}Lines intersect at \alpha_1 = \alpha_2 = ',num2str(p(2)/(1-p(1)),2)]);%Intersect point
text2=['\fontsize{14}\alpha_2 = ', num2str(p(1),2),' \alpha_1 + ',num2str(p(2),2)];%Text for legend
hleg1 = legend('\fontsize{14}Value from simulation','\fontsize{14}\alpha_2 = \alpha_1',text2);%Set up legend
set(hleg1,'Location','NorthWest'); hold off;clear all;%Plot legend